@@ -490,12 +490,15 @@ static void Oops_set_eip(const char *value, addr_t *eip, SYMBOL_SET *ss,
 /*                     Start architecture sensitive code                      */
 /******************************************************************************/
 
+static regex_t     re_Oops_i370_regs;
+static regmatch_t *re_Oops_i370_regs_pmatch;
+
 /* All address arithmetic is done in 64 bit mode, truncate to the result to
  * a valid range for the target.
  */
 static addr_t Oops_truncate_address(addr_t address, const OPTIONS *options)
 {
-    if (options->address_bits == 32) {
+    if (options->address_bits == 32 || strstr(options->target, "i370")) {
 	U32 u32 = address;
 	if (strstr(options->target, "i370"))
 	    u32 &= 0x7fffffff;  /* Really 31 bit addressing on i370 */
@@ -657,6 +660,70 @@ static char *Oops_eip(const char *line, char ***string, int string_max,
     return(NULL);
 }
 
+/* Look for the alpha spinlock stuck line, returns TRUE with string[1]
+ * containing the PC, string[2] containing the previous PC.
+ */
+static int Oops_eip_alpha_spinlock(const char *line, char ***string,
+				   int string_max, OPTIONS *options)
+{
+    int i;
+    static regex_t     re_Oops_eip_alpha_spinlock;
+    static regmatch_t *re_Oops_eip_alpha_spinlock_pmatch;
+    static const char procname[] = "Oops_eip_alpha_spinlock";
+
+    RE_COMPILE(&re_Oops_eip_alpha_spinlock,
+	    "^spinlock stuck at " UNBRACKETED_ADDRESS
+	    ".*owner.*at " UNBRACKETED_ADDRESS,
+	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
+	&re_Oops_eip_alpha_spinlock_pmatch);
+
+    i = regexec(&re_Oops_eip_alpha_spinlock, line,
+	re_Oops_eip_alpha_spinlock.re_nsub+1,
+	re_Oops_eip_alpha_spinlock_pmatch, 0);
+    DEBUG(4, "regexec %d", i);
+    if (i == 0) {
+	re_string_check(re_Oops_eip_alpha_spinlock.re_nsub+1, string_max,
+	    procname);
+	re_strings(&re_Oops_eip_alpha_spinlock, line,
+	    re_Oops_eip_alpha_spinlock_pmatch, string);
+	return(1);
+    }
+    return(0);
+}
+
+/* Look for the sparc spinlock stuck line, returns TRUE with string[1]
+ * containing the lock address, string[2] containing the caller PC,
+ * string[3] containing the owning PC.
+ */
+static int Oops_eip_sparc_spinlock(const char *line, char ***string,
+				   int string_max, OPTIONS *options)
+{
+    int i;
+    static regex_t     re_Oops_eip_sparc_spinlock;
+    static regmatch_t *re_Oops_eip_sparc_spinlock_pmatch;
+    static const char procname[] = "Oops_eip_sparc_spinlock";
+
+    RE_COMPILE(&re_Oops_eip_sparc_spinlock,
+	    "^spin_lock[^ ]*\\(" UNBRACKETED_ADDRESS
+	    ".*stuck at *" UNBRACKETED_ADDRESS
+	    ".*PC\\(" UNBRACKETED_ADDRESS,
+	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
+	&re_Oops_eip_sparc_spinlock_pmatch);
+
+    i = regexec(&re_Oops_eip_sparc_spinlock, line,
+	re_Oops_eip_sparc_spinlock.re_nsub+1,
+	re_Oops_eip_sparc_spinlock_pmatch, 0);
+    DEBUG(4, "regexec %d", i);
+    if (i == 0) {
+	re_string_check(re_Oops_eip_sparc_spinlock.re_nsub+1, string_max,
+	    procname);
+	re_strings(&re_Oops_eip_sparc_spinlock, line,
+	    re_Oops_eip_sparc_spinlock_pmatch, string);
+	return(1);
+    }
+    return(0);
+}
+
 /* Look for the mips ra line, returns start of the relevant hex value */
 static char *Oops_mips_ra(const char *line, char ***string, int string_max)
 {
@@ -771,6 +838,53 @@ static int Oops_sparc_regdump(const char *line, char ***string)
     return 0;
 }
 
+/* Look for the i370 PSW line, returns start of the relevant hex value */
+static char *Oops_i370_psw(const char *line, char ***string, int string_max)
+{
+    int i;
+    static regex_t     re_Oops_i370_psw;
+    static regmatch_t *re_Oops_i370_psw_pmatch;
+    static const char procname[] = "Oops_i370_psw";
+
+    /* Oops 'PSW:' line for i370, PSW at start of line, value is second
+     * address.
+     */
+    RE_COMPILE(&re_Oops_i370_psw,
+	    "^PSW *flags: *"
+	    UNBRACKETED_ADDRESS		/* flags */
+	    " *PSW addr: *"
+	    UNBRACKETED_ADDRESS,
+	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
+	&re_Oops_i370_psw_pmatch);
+
+    i = regexec(&re_Oops_i370_psw, line, re_Oops_i370_psw.re_nsub+1,
+	re_Oops_i370_psw_pmatch, 0);
+    DEBUG(4, "regexec %d", i);
+    if (i == 0) {
+	re_string_check(re_Oops_i370_psw.re_nsub+1, string_max, procname);
+	re_strings(&re_Oops_i370_psw, line, re_Oops_i370_psw_pmatch,
+	    string);
+	return((*string)[re_Oops_i370_psw.re_nsub]);
+    }
+    return(NULL);
+}
+
+/* Set the i370 PSW from the PSW line */
+static void Oops_set_i370_psw(const char *value, SYMBOL_SET *ss,
+                              const OPTIONS *options)
+{
+    static const char procname[] = "Oops_set_i370_psw";
+    addr_t PSW;
+    PSW = hexstring(value);
+    if (errno) {
+	ERROR(" Invalid hex value in PSW line, ignored - '%s'", value);
+	perror(prefix);
+	PSW = 0;
+    }
+    PSW = Oops_truncate_address(PSW, options);
+    add_symbol_n(ss, PSW, 'E', 1, ">>PSW;");
+}
+
 /* Look for the Trace multilines :(.  Returns start of addresses. */
 static const char *Oops_trace(const char *line)
 {
@@ -781,10 +895,15 @@ static const char *Oops_trace(const char *line)
     static regmatch_t *re_Oops_trace_pmatch;
     static const char procname[] = "Oops_trace";
 
-    /* Oops 'Trace' lines. */
+    /* Oops 'Trace' lines.  The ikd patch adds "(nn)" for the stack frame size
+     * after each trace entry, it should appear on the same line as the 
+     * bracketed address.  Alas users have been known to split lines so "(nn)"
+     * appears at the start of the continuation line, look for that as well.
+     * Life would be so much easier without users.
+     */
     RE_COMPILE(&re_Oops_trace,
 	    "^("						     /* 1 */
-	    	    "(Call Trace: )"				     /* 2 */
+		    "(Call Trace: )"				     /* 2 */
     /* alpha */     "|(Trace: )"				     /* 3 */
     /* various */   "|(" BRACKETED_ADDRESS ")"			     /* 4,5 */
     /* ppc */	    "|(Call backtrace:)"			     /* 6 */
@@ -792,6 +911,8 @@ static const char *Oops_trace(const char *line)
     /* arm */	    "|Function entered at (" BRACKETED_ADDRESS ")"   /* 8,9 */
     /* sparc64 */   "|Caller\\[" UNBRACKETED_ADDRESS "\\]"	     /* 10 */
     /* i386 */	    "|(" REVBRACKETED_ADDRESS ")"		     /* 11,12 */
+    /* ikd patch */ "|(\\([0-9]+\\) *(" BRACKETED_ADDRESS "))"	     /* 13,14,15 */
+    /* i370 */	    "|([0-9]+ +base=0x" UNBRACKETED_ADDRESS ")"	     /* 16,17 */
 	    ")",
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
 	&re_Oops_trace_pmatch);
@@ -822,6 +943,11 @@ static const char *Oops_trace(const char *line)
 	    trace_line = 3;
 	    start = line + re_Oops_trace_pmatch[10].rm_so;
 	}
+	else if (MATCHED(17)) {
+	    /* i370 only line, one unbracketed address */
+	    trace_line = 3;
+	    start = line + re_Oops_trace_pmatch[17].rm_so;
+	}
 	else if (MATCHED(11)) {
 	    /* Reversed addresses for spinloops :( */
 	    trace_line = 1;
@@ -830,6 +956,9 @@ static const char *Oops_trace(const char *line)
 	else if (trace_line == 1 && MATCHED(4))
 	    /* Most continuation lines */
 	    start = line + re_Oops_trace_pmatch[4].rm_so;
+	else if (trace_line == 1 && MATCHED(14))
+	    /* incorrectly split trace lines from ikd patch */
+	    start = line + re_Oops_trace_pmatch[14].rm_so;
 	else if (trace_line == 2 && MATCHED(7))
 	    /* ppc continuation line */
 	    start = line + re_Oops_trace_pmatch[7].rm_so;
@@ -839,7 +968,7 @@ static const char *Oops_trace(const char *line)
     else
 	trace_line = 0;
     if (trace_line) {
-        if (trace_line == 3)
+	if (trace_line == 3)
 	    trace_line = 0;	/* no continuation lines */
 	return(start);
     }
@@ -852,8 +981,16 @@ static void Oops_trace_line(const char *line, const char *p, SYMBOL_SET *ss)
     char **string = NULL;
     regex_t *pregex;
     regmatch_t *pregmatch;
+    static regex_t     re_ikd;
+    static regmatch_t *re_ikd_pmatch;
     static const char procname[] = "Oops_trace_line";
 
+    /* ikd adds "(nn)" for stack frame size after each 'Trace' field. */
+    RE_COMPILE(&re_ikd,
+	    "^(\\([0-9]+\\) *)",
+	REG_NEWLINE|REG_EXTENDED,
+	&re_ikd_pmatch);
+
     /* ppc does not bracket its addresses */
     if (isxdigit(*p)) {
 	pregex = &re_unbracketed_address;
@@ -878,6 +1015,8 @@ static void Oops_trace_line(const char *line, const char *p, SYMBOL_SET *ss)
 	}
 	else if (strncmp(p, "from ", 5) == 0)
 	    p += 5;     /* arm does "address from address" */
+	else if (regexec(&re_ikd, p, re_ikd.re_nsub+1, re_ikd_pmatch, 0) == 0)
+	    p += re_ikd_pmatch[0].rm_eo;  /* step over ikd stack frame size */
 	else
 	    break;
     }
@@ -887,6 +1026,67 @@ static void Oops_trace_line(const char *line, const char *p, SYMBOL_SET *ss)
     re_strings_free(pregex, &string);
 }
 
+/* Decide if the line contains i370 registers.  Returns first register name. */
+static const char *Oops_i370_regs(const char *line)
+{
+    int i;
+    static const char procname[] = "Oops_i370_regs";
+
+    RE_COMPILE(&re_Oops_i370_regs,
+	    "^ *(r[0-9]{1,2}): *" UNBRACKETED_ADDRESS,	/* 1, 2 */
+	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
+	&re_Oops_i370_regs_pmatch);
+
+    i = regexec(&re_Oops_i370_regs, line, re_Oops_i370_regs.re_nsub+1,
+	re_Oops_i370_regs_pmatch, 0);
+    DEBUG(4, "regexec %d", i);
+    if (i == 0)
+	return(line + re_Oops_i370_regs_pmatch[0].rm_so);
+    return(NULL);
+}
+
+/* Process a i370 register line, extract addresses */
+static void Oops_set_i370_regs(const char *line, const char *p,
+			       SYMBOL_SET *ss, const OPTIONS *options)
+{
+    addr_t reg;
+    char regname[7];
+    char **string = NULL;
+    static const char procname[] = "Oops_set_i370_regs";
+
+    /* Loop over i370 register names and unbracketed addresses */
+    while (1) {
+	if (regexec(&re_Oops_i370_regs, p, re_Oops_i370_regs.re_nsub+1,
+	    re_Oops_i370_regs_pmatch, 0) == 0) {
+	    re_strings(&re_Oops_i370_regs, p, re_Oops_i370_regs_pmatch, &string);
+	    reg = hexstring(string[2]);		/* contents */
+	    if (errno) {
+		ERROR(" Invalid hex value in i370 register line, ignored - '%s'",
+		      string[2]);
+		perror(prefix);
+		reg = 0;
+	    }
+	    reg = Oops_truncate_address(reg, options);
+	    if (reg > 1024) {
+		strcpy(regname, ">>");
+		strncpy(regname+2, string[1], sizeof(regname-2));
+		if (regname[4] == '\0')
+		    strcpy(regname+4, " ;");
+		else
+		    strcpy(regname+5, ";");
+		add_symbol_n(ss, reg, 'R', 1, regname);
+	    }
+	    p += re_Oops_i370_regs_pmatch[0].rm_eo;
+	}
+	else
+	    break;
+    }
+
+    if (*p)
+	WARNING("garbage '%s' at end of i370 register line ignored", p);
+    re_strings_free(&re_Oops_i370_regs, &string);
+}
+
 /* Do pattern matching to decide if the line should be printed.  When reading a
  * syslog containing multiple Oops, you need the intermediate data (registers,
  * tss etc.) to go with the decoded text.  Sets text to the start of the useful
@@ -1003,12 +1203,26 @@ static int Oops_print(const char *line, const char **text, char ***string,
      * is ready.
      *
      * string 9 is defined if the text is 'Trace: ' (alpha).
-     * string 10 is defined if the text is 'Call backtrace:' (ppc).
+     * string 10 is defined if the text is 'Call backtrace:' (ppc, i370).
      * string 11 is defined if the text is 'bh:' (i386).  Stack addresses are
      * on the next line.  In our typical inconsistent manner, the bh: stack
      * addresses are different from every other address, they are <[...]>
      * instead of [<...>] so define yet another re, string 12.  Sigh.
      *
+     * The ikd patch adds "(nn)" for the stack frame size after each trace
+     * entry, it should appear on the same line as the bracketed address.  Alas
+     * users have been known to split lines so "(nn)" appears at the start of
+     * the continuation line, look for that as well.  Life would be so much
+     * easier without users.  Andi Kleen's multi cpu traceback patch adds the
+     * module name as "(name)" after addresses.  Strings 13 and 14 are
+     * a special case of strings 6 and 7 to handle "(nn)" and "(name)",
+     * in fact anything in "()" between addresses is ignored.
+     *
+     * Both ppc and i370 use 'Call backtrace:' but the i370 data is completely
+     * different from anything else.  It starts on a separate line and consists
+     * of multiple lines, each containing a number (trace depth), base=, link=,
+     * stack=.
+     *
      * Some strings indicate stack data (S), some indicate trace data (T).
      */
     RE_COMPILE(&re_Oops_print_s,
@@ -1021,9 +1235,13 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* various */   "|(" BRACKETED_ADDRESS ")"		/* 6,7 T */
     /* various */   "|(Version_[0-9]+)"			/*  8 */
     /* alpha */	    "|(Trace: )"			/*  9  T */
-    /* ppc */	    "|(Call backtrace:)"		/* 10  T */
+    /* ppc, i370 */ "|(Call backtrace:)"		/* 10  T */
     /* i386 */	    "|(bh:)"				/* 11  T */
     /* i386 */	    "|" REVBRACKETED_ADDRESS		/* 12  T */
+    /* ikd/AK */    "|(\\([^ ]+\\) *"			/* 13  T */
+		      BRACKETED_ADDRESS ")"		/* 14    */
+    /* i370 */	    "|([0-9]+ +base=)"			/* 15  T */
+
 
     /* order does not matter from here on */
     
@@ -1031,6 +1249,8 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* various */   "|Code *: "
     /* various */   "|Kernel panic"
     /* various */   "|In swapper task"
+    /* various */   "|kmem_free"
+    /* various */   "|swapper"
 
     /* i386 2.0 */  "|Corrupted stack page"
     /* i386 */	    "|invalid operand: "
@@ -1063,14 +1283,16 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* alpha */	    "|Forwarding unaligned exception"
     /* alpha */	    "|: unhandled unaligned exception"
     /* alpha */	    "|pc *="
-    /* alpha */	    "|r[0-9]+ *="
+    /* alpha */	    "|[rvtsa][0-9]+ *="	/* Changed from r to [vtsa] in 2.2.14 */
     /* alpha */	    "|gp *="
+    /* alpha */	    "|spinlock stuck"
     /* any other alpha lines to print? */
 
     /* sparc */	    "|tsk->"
     /* sparc */	    "|PSR: "
     /* sparc */	    "|[goli]0: "
     /* sparc */	    "|Instruction DUMP: "
+    /* sparc */	    "|spin_lock"
     /* any other sparc lines to print? */
 
     /* sparc64 */   "|TSTATE: "
@@ -1102,6 +1324,23 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* arm */	    "|Control:"
     /* any other arm lines to print? */
 
+    /* ikd patch */ "|WARNING:"
+    /* ikd patch */ "|this_stack:"
+    /* ikd patch */ "|i:"
+    /* any other ikd lines to print? */
+
+    /* i370 */	    "|PSW"
+    /* i370 */	    "|cr[0-9]+:"
+    /* i370 */	    "|r[0-9]+:"
+    /* i370 */	    "|machine check"
+    /* i370 */	    "|Exception in "
+    /* i370 */	    "|Program Check "
+    /* i370 */	    "|System restart "
+    /* i370 */	    "|IUCV "
+    /* i370 */	    "|unexpected external "
+    /* i370 */	    "|Kernel stack "
+    /* any other i370 lines to print? */
+
 		")",
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
 	&re_Oops_print_s_pmatch);
@@ -1127,11 +1366,12 @@ static int Oops_print(const char *line, const char **text, char ***string,
 	stack_line = 0;
     /* Trace lines */
     if (!MATCHED(5) && !MATCHED(6) && !MATCHED(9) && !MATCHED(10) &&
-	!MATCHED(11) && !MATCHED(12))
+	!MATCHED(11) && !MATCHED(12) && !MATCHED(13) && !MATCHED(15))
 	trace_line = 0;
-    else if (MATCHED(5) || MATCHED(9) || MATCHED(10) || MATCHED(11))
+    else if (MATCHED(5) || MATCHED(9) || MATCHED(10) || MATCHED(11) ||
+             MATCHED(15))
 	trace_line = 1;
-    else if (trace_line && !MATCHED(6) && !MATCHED(12))
+    else if (trace_line && !MATCHED(6) && !MATCHED(12) && !MATCHED(13))
 	trace_line = 0;
     if (i == 0) {
 	print = 1;
@@ -1139,7 +1379,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
 	    print = 0;
 	    DEBUG(4, "ambiguous stack line ignored");
 	}
-	if ((MATCHED(6) || MATCHED(12)) && !trace_line) {
+	if ((MATCHED(6) || MATCHED(12) || MATCHED(13)) && !trace_line) {
 	    print = 0;
 	    DEBUG(4, "ambiguous trace line ignored");
 	}
@@ -1184,6 +1424,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* various */   "Unable to handle kernel"
     /* various */   "|Aiee"      /* anywhere in text is a bad sign (TM) */
     /* various */   "|die_if_kernel"  /* ditto */
+    /* various */   "|NMI "
 
     /* alpha */     "|\\([0-9]\\): Oops "
     /* alpha */     "|: memory violation"
@@ -1214,7 +1455,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* ppc */       "|bad area pc "
     /* ppc */       "|NIP: "
 
-    /* mips */      "| ra *="
+    /* mips */      "| ra *=="
 
 		,
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
@@ -1223,7 +1464,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
     if (!print) {
 	i = regexec(&re_Oops_print_a, *text, re_Oops_print_a.re_nsub+1,
 	    re_Oops_print_a_pmatch, 0);
-        DEBUG(4, "regexec anywhere %d", i);
+	DEBUG(4, "regexec anywhere %d", i);
 	if (i == 0)
 	    print = 1;
     }
@@ -1245,18 +1486,18 @@ static const char *Oops_code(const char *line, char ***string, int string_max)
      * brackets the PC in '<' and '>'.  arm brackets the PC in '(' and ')'.
      */
     RE_COMPILE(&re_Oops_code,
-	    	"^("				/*  1 */
-    /* sparc */   "(Instruction DUMP)"		/*  2 */
+		"^("				/*  1 */
+    /* various */ "(Instruction DUMP)"		/*  2 */
     /* various */ "|(Code *)"			/*  3 */
-	    	")"
-	    	": +"
-	    	"("				/*  4 */
-	      	  "(general protection.*)"
-	      	  "|(<[0-9]+>)"
-	      	  "|(([<(]?[0-9a-fA-F]+[>)]? +)+[<(]?[0-9a-fA-F]+[>)]?)"
-	    	")"
-	    	"(.*)$"			/* trailing garbage */
-	    	,
+		")"
+		": +"
+		"("				/*  4 */
+		  "(general protection.*)"
+		  "|(<[0-9]+>)"
+		  "|(([<(]?[0-9a-fA-F]+[>)]? +)+[<(]?[0-9a-fA-F]+[>)]?)"
+		")"
+		"(.*)$"			/* trailing garbage */
+		,
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
 	&re_Oops_code_pmatch);
 
@@ -1456,12 +1697,35 @@ int Oops_read(OPTIONS *options)
 		if ((start = Oops_eip(text, &string, MAX_STRINGS, ibfd,
 				      options)))
 		    Oops_set_eip(start, &eip, &ss_format, me, ibfd, options);
+		if (Oops_eip_alpha_spinlock(text, &string, MAX_STRINGS,
+					    options)) {
+		    /* Set the eip and previous user from the alpha spinlock
+		     * stuck line.  YASC, this line contains both the eip and
+		     * the equivalent of a trace entry.
+		     */
+		    Oops_set_eip(string[1], &eip, &ss_format, me, ibfd, options);
+		    Oops_trace_line(line, string[2], &ss_format);
+		}
+		if (Oops_eip_sparc_spinlock(text, &string, MAX_STRINGS,
+					    options)) {
+		    /* Set the eip and previous user from the sparc spinlock
+		     * stuck line.  YASC, this line contains the lock and two
+		     * PC entries.
+		     */
+		    Oops_set_eip(string[2], &eip, &ss_format, me, ibfd, options);
+		    Oops_set_eip(string[3], &eip, &ss_format, me, ibfd, options);
+		    Oops_trace_line(line, string[1], &ss_format);
+		}
 		if ((start = Oops_mips_ra(text, &string, MAX_STRINGS)))
 		    Oops_set_mips_ra(start, &ss_format);
 		if ((start = Oops_sparc_oi7(text, &string, MAX_STRINGS)))
 		    Oops_set_sparc_oi7(start, &string, &ss_format);
+		if ((start = Oops_i370_psw(text, &string, MAX_STRINGS)))
+		    Oops_set_i370_psw(start, &ss_format, options);
 		if ((start = Oops_trace(text)))
 		    Oops_trace_line(text, start, &ss_format);
+		if ((start = Oops_i370_regs(text)))
+		    Oops_set_i370_regs(text, start, &ss_format, options);
 		if ((start = Oops_code(text, &string, MAX_STRINGS))) {
 		    /* In case no EIP line was seen */
 		    Oops_set_default_ta(me, ibfd, options);
@@ -1487,8 +1751,8 @@ int Oops_read(OPTIONS *options)
 	}
 	if (ss_format.used) {
 	    if (options->target &&
-	        strstr(options->target, "sparc") == 0 &&
-	        sparc_regdump)
+		strstr(options->target, "sparc") == 0 &&
+		sparc_regdump)
 		;	/* sparc regdump comes *after* code, ignore :( */
 	    else
 		WARNING("Code line not seen, dumping what data is available");
@@ -1501,7 +1765,7 @@ int Oops_read(OPTIONS *options)
 
 #ifdef TIME_RE
     for (i = 0; i < sizeof(diff)/sizeof(diff[0]); ++i)
-        printf("diff %d %d %lld %lld\n", i, count[i], diff[i], count[i] ? diff[i]/count[i] : 0);
+	printf("diff %d %d %lld %lld\n", i, count[i], diff[i], count[i] ? diff[i]/count[i] : 0);
 #endif
 
     if (ibfd && !bfd_close(ibfd)) {
